@@ -25,10 +25,7 @@ class BotXAPIListChatResponsePayload(VerifiedPayloadBaseModel):
     result: List[Union[BotXAPIListChatResult, Dict[str, Any]]]  # noqa: WPS234
 
     def to_domain(self) -> List[ChatListItem]:
-        if any(isinstance(chat_item, dict) for chat_item in self.result):
-            logger.warning("One or more unsupported chat types skipped")
-
-        return [
+        chats_list = [
             ChatListItem(
                 chat_id=chat_item.group_chat_id,
                 chat_type=convert_chat_type_to_domain(chat_item.chat_type),
@@ -43,6 +40,11 @@ class BotXAPIListChatResponsePayload(VerifiedPayloadBaseModel):
             if isinstance(chat_item, BotXAPIListChatResult)
         ]
 
+        if len(chats_list) != len(self.result):
+            logger.warning("One or more unsupported chat types skipped")
+
+        return chats_list
+
 
 class ListChatsMethod(AuthorizedBotXMethod):
     async def execute(self) -> BotXAPIListChatResponsePayload:
